@@ -3,6 +3,7 @@ import dataclasses
 import typing
 
 import numpy as np
+import scipy.ndimage
 
 from tike.ptycho.object import ObjectOptions
 from tike.ptycho.position import PositionOptions, check_allowed_positions
@@ -26,11 +27,12 @@ class IterativeOptions(abc.ABC):
     """The name of the batch selection method. Choose from the cluster methods
     in the tike.random module."""
 
-    costs: typing.List[float] = dataclasses.field(
+    costs: typing.List[typing.List[float]] = dataclasses.field(
         init=False,
         default_factory=list,
     )
-    """The objective function value at previous iterations."""
+    """The objective function value at previous iterations. One list is
+    returned for each mini-batch."""
 
     num_iter: int = 1
     """The number of epochs to process before returning."""
@@ -159,3 +161,101 @@ class PtychoParameters():
             self.psi,
             self.probe.shape,
         )
+
+    def resample(self, factor: float, interp):
+        """Return a new PtychoParameter with the parameters scaled."""
+        interp = _resize_fft if interp is None else interp
+        return PtychoParameters(
+            probe=interp(self.probe, factor),
+            psi=_resize_spline(self.psi, factor),
+            scan=self.scan * factor,
+            eigen_probe=interp(self.eigen_probe, factor)
+            if self.eigen_probe is not None else None,
+            eigen_weights=self.eigen_weights,
+            algorithm_options=self.algorithm_options,
+            probe_options=self.probe_options.resample(factor)
+            if self.probe_options is not None else None,
+            object_options=self.object_options.resample(factor)
+            if self.object_options is not None else None,
+            position_options=self.position_options.resample(factor)
+            if self.position_options is not None else None,
+        )
+
+
+def _resize_spline(x, f):
+    return scipy.ndimage.zoom(
+        x,
+        zoom=[1] * (x.ndim - 2) + [f, f],
+        grid_mode=True,
+        prefilter=False,
+    )
+
+
+def _resize_cv(x, f, interpolation):
+    import tike.view
+    x_shape = x.shape
+    x = x.reshape(-1, *x_shape[-2:])
+    x1 = [
+        tike.view.resize_complex_image(
+            i,
+            scale_factor=(f, f),
+            interpolation=interpolation,
+        ) for i in x
+    ]
+    return np.asarray(x1).reshape(*x_shape[:-2], *x1[0].shape[-2:])
+
+
+def _resize_linear(x, f):
+    return _resize_cv(x, f, 1)
+
+
+def _resize_cubic(x, f):
+    return _resize_cv(x, f, 2)
+
+
+def _resize_lanczos(x, f):
+    return _resize_cv(x, f, 4)
+
+
+def crop_fourier_space(x, w: int):
+    """Crop x assuming a 2D frequency space image with zero frequency in corner."""
+    assert x.shape[-2] == x.shape[-1], "Only works on square arrays right now."
+    half1 = w // 2
+    half0 = w - half1
+    # yapf: disable
+    return x[
+        ..., np.r_[0:half0, (x.shape[-1] - half1):x.shape[-1]],
+    ][
+        ..., np.r_[0:half0, (x.shape[-2] - half1):x.shape[-2]], :,
+    ]
+    # yapf: enable
+
+
+def pad_fourier_space(x, w: int):
+    """Pad x assuming a 2D frequency space image with zero frequency in corner."""
+    assert x.shape[-2] == x.shape[-1], "Only works on square arrays right now."
+    half1 = x.shape[-1] // 2
+    half0 = x.shape[-1] - half1
+    new_x = np.zeros_like(x, shape=(*x.shape[:-2], w, w))
+    new_x[..., 0:half0, np.r_[0:half0, (w - half1):w]] = x[..., 0:half0, :]
+    new_x[..., -half1:w, np.r_[0:half0, (w - half1):w]] = x[..., -half1:, :]
+    return new_x
+
+
+def _resize_fft(x, f):
+    """Use Fourier interpolation to resize/resample the last 2 dimensions of x"""
+    if f == 1:
+        return x
+    crop_or_pad = crop_fourier_space if f < 1 else pad_fourier_space
+    return np.fft.ifft2(
+        crop_or_pad(
+            np.fft.fft2(
+                x,
+                norm='ortho',
+                axes=(-2, -1),
+            ),
+            w=int(x.shape[-1] * f),
+        ),
+        norm='ortho',
+        axes=(-2, -1),
+    )
